
function saveAsOBJ obj fileName =
(
	fs = createFile fileName

	tmesh = snapshotAsMesh obj
	num_verts = tmesh.numverts
	num_faces = tmesh.numfaces
	
	format "# %,%\n" num_verts num_faces to:fs
	for v = 1 to num_verts do
	(
		vert = getVert tmesh v
		format "v % % % \n" vert.x vert.y vert.z to:fs
	)
	for f = 1 to num_faces do
	(
		face = getFace tmesh f
		format "f % % % \n" (face.x as integer) (face.y as integer) (face.z as integer) to:fs
	)
	
	close fs
)

function loadOBJ fileName =
(
	fs = openFile fileName
	
	-- OBJ elements
	vert_array = #()
	face_array = #()
	
	if(fs != undefined) do
	(
		print (format "Loading mesh %.." fileName)
		
		while not eof fs do
		(
			lineText = readLine fs 
			data = filterString lineText " \t"

			type = data[1] as string
			
			-- vertices
			if(type == "v") then
			(
				x = data[2] as float
				y = data[3] as float
				z = data[4] as float		
				
				v = [x, y, z]
				append vert_array v
			)
			
			-- triangles
			if(type == "f") then
			(
				face = [ data[2] as integer,  data[3] as integer, data[4] as integer]
				append face_array face
			)
		)
		
		m = mesh vertices:vert_array faces:face_array
		
		basenameExt = filterString fileName "/"
		basename = filterString basenameExt[basenameExt.count] "."
		m.name = basename[1]
		
		-- Remove smoothing
		convertToMesh m
		meshop.autoSmooth m #{1..m.numfaces} 0
		
			
		close fs
		
		return m
	)
	
	return "ERROR"
)

function saveOFF obj fileName =
(
	--fileName = getSaveFileName caption:"Save OFF" types:"OFF object file (*.off)|*.off|All Files (*.*)|*.*|"
	
	fs = createFile fileName
	obj = copy obj

	convertToMesh obj
	
	num_verts = obj.numverts
	num_faces = obj.numfaces
	
	format "OFF\n" to:fs
	format "% % 0\n" num_verts num_faces to:fs
	
	for v = 1 to num_verts do
	(
		vert = getVert obj v
		format "% % %\n" vert[1] vert[2] vert[3] to:fs
	)

	for f = 1 to num_faces do
	(
		face = getFace obj f
		
		v1 = (face[1] as integer) - 1
		v2 = (face[2] as integer) - 1
		v3 = (face[3] as integer) - 1
		
		format "3 % % %\n"  v1 v2 v3 to:fs
	)
	
	delete obj
	
	close fs
)

function loadOFF fileName =
(
	-- Get filename
	--fileName = getOpenFileName caption:"Open OFF" types:"OFF object file (*.off)|*.off|All Files (*.*)|*.*|"
	
	if fileName != undefined then
	(
		fs = openFile fileName

		if fs != undefined then
		(
			-- Read OFF first line
			inputData = readLine fs 

			-- Read num vertices + faces
			inputData = readLine fs 

			data = filterString inputData " \t"

			vert_count = (data[1] as integer)
			num_faces = (data[2] as integer)

			-- OFF elements
			vert_array = #()
			face_array = #()
			 
			-- Verts
			for i = 1 to vert_count do
			(
				inputData = readLine fs 
				data = filterString inputData " \t"
				
				x = data[1] as float
				y = data[2] as float
				z = data[3] as float
				
				v = [x, y, z]
				
				append vert_array v
			)

			--print vert_array

			-- Faces
			for i = 1 to num_faces do
			(
				inputData = readLine fs 
				data = filterString inputData " \t"

				numFaceVerts = data[1] as integer

				face = [1 + data[2] as integer, 1 + data[3] as integer, 1 + data[4] as integer]
				

				append face_array face
			)

			--print face_array

			m = mesh vertices:vert_array faces:face_array
			
			basenameExt = filterString fileName "\\"
			basename = filterString basenameExt[basenameExt.count] "."
			m.name = basename[1]
			
			-- Remove smoothing
			convertToMesh m
			meshop.autoSmooth m #{1..m.numfaces} 0
			
			CenterPivot m
			
			close fs
			
			return m
		)
	)
)
