function outputFilename = fixMesh(filename)
	addpath('src', genpath('external'), 'maxflow', 'selfintersect', 'winding_number');

    % Load mesh
    [V,F] = load_mesh(filename);

    % print some statistics
    %statistics(V,F)
    % Clean up mesh for TetGen
    [SV,SF] = clean(V,F, 'MinDist',1e-6,'MinAngle',-1,'MinArea',-1,'SelfIntersections','mesh');

    % Use TetGen to mesh CDT
    [DV,DEle,DF,DN] = cdt(SV,SF,'TetgenFlags','-Y','UseBoundingBox',true);

    display('Will compute winding_number now..');
    w = winding_number(V,F,barycenter(DV,DEle))/(4*pi);
    display('Done!');

    if sum(w)<0
      warning('Flipping sign of w to match convention');
      w = -w;
    end
    % Cut according to w
    [CEle,cut,AS,AD] = graphcut(DV,DEle,DN,w,'SmoothnessWeight',1e-5,'VolumeWeight',0);
    CEle = DEle(1==cut,:);
    CF = boundary_faces(CEle);
    CV = DV;

    % if you have medit set to true and edit medit.m accordingly
    has_medit = true;
    if has_medit
      % Visualize input
      input_medit(V,F);
      % Visualize winding number
      %[s,r] = medit(DV,DEle,DF,'Data',w);
      % Visualize solution
      [s,r] = medit(CV,CEle,CF);
    end

    %command = ['tetview.exe ' r ' &'];
    %system(command);
	
	% Save as mesh under FILENAME_fixed.obj
    [pathstr, name, ext] = fileparts(filename);
    outputFilename = [name '_fixed.obj'];
    writeOBJ(outputFilename, CV, CF);
end
